==> open-cluster-management-apps-model-6.1.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/SourceFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SourceFluentImpl<A extends SourceFluent<A>> extends BaseFluent<A> implements SourceFluent<A>{
  public SourceFluentImpl() {
  }
  public SourceFluentImpl(Source instance) {
    this.withGit(instance.getGit()); 
    this.withGithub(instance.getGithub()); 
    this.withHelmRepo(instance.getHelmRepo()); 
    this.withType(instance.getType()); 
  }
  private GitBuilder git;
  private GitHubBuilder github;
  private HelmRepoBuilder helmRepo;
  private String type;
  
  /**
   * This method has been deprecated, please use method buildGit instead.
   * @return The buildable object.
   */
  @Deprecated
  public Git getGit() {
    return this.git!=null ?this.git.build():null;
  }
  public Git buildGit() {
    return this.git!=null ?this.git.build():null;
  }
  public A withGit(Git git) {
    _visitables.get("git").remove(this.git);
    if (git!=null){ this.git= new GitBuilder(git); _visitables.get("git").add(this.git);} else { this.git = null; _visitables.get("git").remove(this.git); } return (A) this;
  }
  public Boolean hasGit() {
    return this.git != null;
  }
  public SourceFluent.GitNested<A> withNewGit() {
    return new SourceFluentImpl.GitNestedImpl();
  }
  public SourceFluent.GitNested<A> withNewGitLike(Git item) {
    return new SourceFluentImpl.GitNestedImpl(item);
  }
  public SourceFluent.GitNested<A> editGit() {
    return withNewGitLike(getGit());
  }
  public SourceFluent.GitNested<A> editOrNewGit() {
    return withNewGitLike(getGit() != null ? getGit(): new GitBuilder().build());
  }
  public SourceFluent.GitNested<A> editOrNewGitLike(Git item) {
    return withNewGitLike(getGit() != null ? getGit(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildGithub instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitHub getGithub() {
    return this.github!=null ?this.github.build():null;
  }
  public GitHub buildGithub() {
    return this.github!=null ?this.github.build():null;
  }
  public A withGithub(GitHub github) {
    _visitables.get("github").remove(this.github);
    if (github!=null){ this.github= new GitHubBuilder(github); _visitables.get("github").add(this.github);} else { this.github = null; _visitables.get("github").remove(this.github); } return (A) this;
  }
  public Boolean hasGithub() {
    return this.github != null;
  }
  public SourceFluent.GithubNested<A> withNewGithub() {
    return new SourceFluentImpl.GithubNestedImpl();
  }
  public SourceFluent.GithubNested<A> withNewGithubLike(GitHub item) {
    return new SourceFluentImpl.GithubNestedImpl(item);
  }
  public SourceFluent.GithubNested<A> editGithub() {
    return withNewGithubLike(getGithub());
  }
  public SourceFluent.GithubNested<A> editOrNewGithub() {
    return withNewGithubLike(getGithub() != null ? getGithub(): new GitHubBuilder().build());
  }
  public SourceFluent.GithubNested<A> editOrNewGithubLike(GitHub item) {
    return withNewGithubLike(getGithub() != null ? getGithub(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildHelmRepo instead.
   * @return The buildable object.
   */
  @Deprecated
  public HelmRepo getHelmRepo() {
    return this.helmRepo!=null ?this.helmRepo.build():null;
  }
  public HelmRepo buildHelmRepo() {
    return this.helmRepo!=null ?this.helmRepo.build():null;
  }
  public A withHelmRepo(HelmRepo helmRepo) {
    _visitables.get("helmRepo").remove(this.helmRepo);
    if (helmRepo!=null){ this.helmRepo= new HelmRepoBuilder(helmRepo); _visitables.get("helmRepo").add(this.helmRepo);} else { this.helmRepo = null; _visitables.get("helmRepo").remove(this.helmRepo); } return (A) this;
  }
  public Boolean hasHelmRepo() {
    return this.helmRepo != null;
  }
  public SourceFluent.HelmRepoNested<A> withNewHelmRepo() {
    return new SourceFluentImpl.HelmRepoNestedImpl();
  }
  public SourceFluent.HelmRepoNested<A> withNewHelmRepoLike(HelmRepo item) {
    return new SourceFluentImpl.HelmRepoNestedImpl(item);
  }
  public SourceFluent.HelmRepoNested<A> editHelmRepo() {
    return withNewHelmRepoLike(getHelmRepo());
  }
  public SourceFluent.HelmRepoNested<A> editOrNewHelmRepo() {
    return withNewHelmRepoLike(getHelmRepo() != null ? getHelmRepo(): new HelmRepoBuilder().build());
  }
  public SourceFluent.HelmRepoNested<A> editOrNewHelmRepoLike(HelmRepo item) {
    return withNewHelmRepoLike(getHelmRepo() != null ? getHelmRepo(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SourceFluentImpl that = (SourceFluentImpl) o;
    if (git != null ? !git.equals(that.git) :that.git != null) return false;
    if (github != null ? !github.equals(that.github) :that.github != null) return false;
    if (helmRepo != null ? !helmRepo.equals(that.helmRepo) :that.helmRepo != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(git,  github,  helmRepo,  type,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (git != null) { sb.append("git:"); sb.append(git + ","); }
    if (github != null) { sb.append("github:"); sb.append(github + ","); }
    if (helmRepo != null) { sb.append("helmRepo:"); sb.append(helmRepo + ","); }
    if (type != null) { sb.append("type:"); sb.append(type); }
    sb.append("}");
    return sb.toString();
  }
  class GitNestedImpl<N> extends GitFluentImpl<SourceFluent.GitNested<N>> implements SourceFluent.GitNested<N>,Nested<N>{
    GitNestedImpl(Git item) {
      this.builder = new GitBuilder(this, item);
    }
    GitNestedImpl() {
      this.builder = new GitBuilder(this);
    }
    GitBuilder builder;
    public N and() {
      return (N) SourceFluentImpl.this.withGit(builder.build());
    }
    public N endGit() {
      return and();
    }
    
  }
  class GithubNestedImpl<N> extends GitHubFluentImpl<SourceFluent.GithubNested<N>> implements SourceFluent.GithubNested<N>,Nested<N>{
    GithubNestedImpl(GitHub item) {
      this.builder = new GitHubBuilder(this, item);
    }
    GithubNestedImpl() {
      this.builder = new GitHubBuilder(this);
    }
    GitHubBuilder builder;
    public N and() {
      return (N) SourceFluentImpl.this.withGithub(builder.build());
    }
    public N endGithub() {
      return and();
    }
    
  }
  class HelmRepoNestedImpl<N> extends HelmRepoFluentImpl<SourceFluent.HelmRepoNested<N>> implements SourceFluent.HelmRepoNested<N>,Nested<N>{
    HelmRepoNestedImpl(HelmRepo item) {
      this.builder = new HelmRepoBuilder(this, item);
    }
    HelmRepoNestedImpl() {
      this.builder = new HelmRepoBuilder(this);
    }
    HelmRepoBuilder builder;
    public N and() {
      return (N) SourceFluentImpl.this.withHelmRepo(builder.build());
    }
    public N endHelmRepo() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-apps-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/SourceFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SourceFluentImpl<A extends SourceFluent<A>> extends BaseFluent<A> implements SourceFluent<A>{
  public SourceFluentImpl() {
  }
  public SourceFluentImpl(Source instance) {
    if (instance != null) {
      this.withGit(instance.getGit());
      this.withGithub(instance.getGithub());
      this.withHelmRepo(instance.getHelmRepo());
      this.withType(instance.getType());
    }
  }
  private GitBuilder git;
  private GitHubBuilder github;
  private HelmRepoBuilder helmRepo;
  private String type;
  
  /**
   * This method has been deprecated, please use method buildGit instead.
   * @return The buildable object.
   */
  @Deprecated
  public Git getGit() {
    return this.git!=null ?this.git.build():null;
  }
  public Git buildGit() {
    return this.git!=null ?this.git.build():null;
  }
  public A withGit(Git git) {
    _visitables.get("git").remove(this.git);
    if (git!=null){ this.git= new GitBuilder(git); _visitables.get("git").add(this.git);} else { this.git = null; _visitables.get("git").remove(this.git); } return (A) this;
  }
  public Boolean hasGit() {
    return this.git != null;
  }
  public SourceFluentImpl.GitNested<A> withNewGit() {
    return new SourceFluentImpl.GitNestedImpl();
  }
  public SourceFluentImpl.GitNested<A> withNewGitLike(Git item) {
    return new SourceFluentImpl.GitNestedImpl(item);
  }
  public SourceFluentImpl.GitNested<A> editGit() {
    return withNewGitLike(getGit());
  }
  public SourceFluentImpl.GitNested<A> editOrNewGit() {
    return withNewGitLike(getGit() != null ? getGit(): new GitBuilder().build());
  }
  public SourceFluentImpl.GitNested<A> editOrNewGitLike(Git item) {
    return withNewGitLike(getGit() != null ? getGit(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildGithub instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitHub getGithub() {
    return this.github!=null ?this.github.build():null;
  }
  public GitHub buildGithub() {
    return this.github!=null ?this.github.build():null;
  }
  public A withGithub(GitHub github) {
    _visitables.get("github").remove(this.github);
    if (github!=null){ this.github= new GitHubBuilder(github); _visitables.get("github").add(this.github);} else { this.github = null; _visitables.get("github").remove(this.github); } return (A) this;
  }
  public Boolean hasGithub() {
    return this.github != null;
  }
  public SourceFluentImpl.GithubNested<A> withNewGithub() {
    return new SourceFluentImpl.GithubNestedImpl();
  }
  public SourceFluentImpl.GithubNested<A> withNewGithubLike(GitHub item) {
    return new SourceFluentImpl.GithubNestedImpl(item);
  }
  public SourceFluentImpl.GithubNested<A> editGithub() {
    return withNewGithubLike(getGithub());
  }
  public SourceFluentImpl.GithubNested<A> editOrNewGithub() {
    return withNewGithubLike(getGithub() != null ? getGithub(): new GitHubBuilder().build());
  }
  public SourceFluentImpl.GithubNested<A> editOrNewGithubLike(GitHub item) {
    return withNewGithubLike(getGithub() != null ? getGithub(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildHelmRepo instead.
   * @return The buildable object.
   */
  @Deprecated
  public HelmRepo getHelmRepo() {
    return this.helmRepo!=null ?this.helmRepo.build():null;
  }
  public HelmRepo buildHelmRepo() {
    return this.helmRepo!=null ?this.helmRepo.build():null;
  }
  public A withHelmRepo(HelmRepo helmRepo) {
    _visitables.get("helmRepo").remove(this.helmRepo);
    if (helmRepo!=null){ this.helmRepo= new HelmRepoBuilder(helmRepo); _visitables.get("helmRepo").add(this.helmRepo);} else { this.helmRepo = null; _visitables.get("helmRepo").remove(this.helmRepo); } return (A) this;
  }
  public Boolean hasHelmRepo() {
    return this.helmRepo != null;
  }
  public SourceFluentImpl.HelmRepoNested<A> withNewHelmRepo() {
    return new SourceFluentImpl.HelmRepoNestedImpl();
  }
  public SourceFluentImpl.HelmRepoNested<A> withNewHelmRepoLike(HelmRepo item) {
    return new SourceFluentImpl.HelmRepoNestedImpl(item);
  }
  public SourceFluentImpl.HelmRepoNested<A> editHelmRepo() {
    return withNewHelmRepoLike(getHelmRepo());
  }
  public SourceFluentImpl.HelmRepoNested<A> editOrNewHelmRepo() {
    return withNewHelmRepoLike(getHelmRepo() != null ? getHelmRepo(): new HelmRepoBuilder().build());
  }
  public SourceFluentImpl.HelmRepoNested<A> editOrNewHelmRepoLike(HelmRepo item) {
    return withNewHelmRepoLike(getHelmRepo() != null ? getHelmRepo(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SourceFluentImpl that = (SourceFluentImpl) o;
    if (!java.util.Objects.equals(git, that.git)) return false;

    if (!java.util.Objects.equals(github, that.github)) return false;

    if (!java.util.Objects.equals(helmRepo, that.helmRepo)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(git,  github,  helmRepo,  type,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (git != null) { sb.append("git:"); sb.append(git + ","); }
    if (github != null) { sb.append("github:"); sb.append(github + ","); }
    if (helmRepo != null) { sb.append("helmRepo:"); sb.append(helmRepo + ","); }
    if (type != null) { sb.append("type:"); sb.append(type); }
    sb.append("}");
    return sb.toString();
  }
  class GitNestedImpl<N> extends GitFluentImpl<SourceFluentImpl.GitNested<N>> implements SourceFluentImpl.GitNested<N>,Nested<N>{
    GitNestedImpl(Git item) {
      this.builder = new GitBuilder(this, item);
    }
    GitNestedImpl() {
      this.builder = new GitBuilder(this);
    }
    GitBuilder builder;
    public N and() {
      return (N) SourceFluentImpl.this.withGit(builder.build());
    }
    public N endGit() {
      return and();
    }
    
  }
  class GithubNestedImpl<N> extends GitHubFluentImpl<SourceFluentImpl.GithubNested<N>> implements SourceFluentImpl.GithubNested<N>,Nested<N>{
    GithubNestedImpl(GitHub item) {
      this.builder = new GitHubBuilder(this, item);
    }
    GithubNestedImpl() {
      this.builder = new GitHubBuilder(this);
    }
    GitHubBuilder builder;
    public N and() {
      return (N) SourceFluentImpl.this.withGithub(builder.build());
    }
    public N endGithub() {
      return and();
    }
    
  }
  class HelmRepoNestedImpl<N> extends HelmRepoFluentImpl<SourceFluentImpl.HelmRepoNested<N>> implements SourceFluentImpl.HelmRepoNested<N>,Nested<N>{
    HelmRepoNestedImpl(HelmRepo item) {
      this.builder = new HelmRepoBuilder(this, item);
    }
    HelmRepoNestedImpl() {
      this.builder = new HelmRepoBuilder(this);
    }
    HelmRepoBuilder builder;
    public N and() {
      return (N) SourceFluentImpl.this.withHelmRepo(builder.build());
    }
    public N endHelmRepo() {
      return and();
    }
    
  }
  
}
